@@ -1,7 +1,6 @@
-
 /*
 
-Copyright (C) (2004 - 2005) (Venkata Ramana Enaganti) <ramana@intraperson.com>
+Copyright (C) (2004 - 2006) (Venkata Ramana Enaganti) <ramana@intraperson.com>
 
 This program is free software; you can redistribute it and/or 
 modify it under the terms of the GNU General Public License 
@@ -43,6 +42,7 @@ I acknowledge autofs people for any
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <sys/poll.h>
+#include <linux/types.h>
 #include <linux/auto_fs4.h>
 
 #include "miscfuncs.h"
@@ -51,7 +51,7 @@ I acknowledge autofs people for any
 #include "options.h"
 #include "mpacket.h"
 #include "thread.h"
-#include "back.h"
+#include "backup.h"
 #include "module.h"
 #include "dropcap.h"
 #include "lockfile.h"
@@ -243,14 +243,15 @@ static int poll_read( int fd, char *buf, int sz )
 	while( sz )
 	{
 		r = poll( &pf, 1, 1000 );
-		if( self.shutdown ) return 0;
 
-		else if( r == -1 && errno != EINTR )
+		if( r == -1 && errno != EINTR )
 		{
 			msglog( MSG_ERR|LOG_ERRNO, "poll_read: poll" );
 			return -1;
 		}
-		else if( r <= 0 ) continue; /*including errno == EINTR */
+		if( r == 0 && self.shutdown )
+			return 0;
+		if( r <= 0 ) continue; /*including errno == EINTR */
 
 		while( ( n = read( fd, buf, sz ) ) == -1 &&
 				errno == EINTR );
@@ -347,7 +348,7 @@ static void handle_missing( Packet *pkt )
 
 	/* any backup running or 
 	   entry under process? stop it*/
-	back_remove( name, name != mname );
+	backup_remove( name, name != mname );
 
 	if( mname != name && ! workon_name( name ) )
 		return missing_exit( mname, NULL, wqt, SEND_FAIL );
@@ -475,10 +476,10 @@ static void handle_expire( Packet *pkt )
 		{
 			n = self.multi_prefix == *name ? name + 1 : name;
 			if( ! multipath_dec( n ) && ! self.stop )
-				back_add( n, path );
+				backup_add( n, path );
 		}
 		else if ( ! self.stop )
-			back_add( name, path );
+			backup_add( name, path );
 
 		send_ready( wqt );
 	}
@@ -512,7 +513,7 @@ static void handle_events( int fd )
 					sizeof(*autopkt) ) != 1 )
 			return;
 
-		if( autopkt->hdr.proto_version != AUTOFS_PROTO_VERSION )
+		if( autopkt->hdr.proto_version != AUTODIR_PROTO_DEFAULT )
 		{
 			msglog( MSG_ALERT, "autofs protocol '%d' not supported",
 					autopkt->hdr.proto_version );
@@ -689,7 +690,7 @@ int main( int argc, char *argv[] )
 
 	/*thread starting initializations
 	  should be done only after forking*/
-	back_init();
+	backup_init();
 
 	lockfile_init( self.pid, self.module_name );
 
@@ -716,7 +717,7 @@ int main( int argc, char *argv[] )
 		msglog( MSG_FATAL, "could not start signal handler thread" );
 
 	mount_autodir( autodir.path, self.pgrp, self.pid,
-			AUTOFS_MIN_PROTO_VERSION, AUTOFS_MAX_PROTO_VERSION );
+			AUTODIR_PROTO_MIN, AUTODIR_PROTO_MAX );
 
 	if( ioctl( autodir.ioctlfd, AUTOFS_IOC_PROTOVER, &autodir.proto ) == -1 )
 		msglog( MSG_FATAL|LOG_ERRNO, "ioctl: AUTOFS_IOC_PROTOVER" );
@@ -724,14 +725,14 @@ int main( int argc, char *argv[] )
 	timeout = autodir.time_out;
 	ioctl( autodir.ioctlfd, AUTOFS_IOC_SETTIMEOUT, &timeout );
 
-	/*only versin 4 is supported*/
-	if( autodir.proto != AUTOFS_PROTO_VERSION )
+	if( autodir.proto != AUTODIR_PROTO_DEFAULT )
 		msglog( MSG_FATAL, "unsupported autofs protocol version" );
 
 	expire_start( autodir.time_out, autodir.ioctlfd, &self.shutdown );
 
 	/*main loop*/
 	handle_events( autodir.k_pipe );
+
 	self.stop = 1;
         backup_stop_set();
         lockfile_stop_set();
@@ -741,7 +742,7 @@ int main( int argc, char *argv[] )
 	expire_stop();
 	backup_stop();
 
-	/* wait for all missing threads to finish*/
+	/* wait for all missing handle threads to finish*/
 	thread_cache_stop( &self.expire_tc );
 
 	/* wait for all expiry threads to finish*/
