@@ -26,7 +26,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <sys/types.h>
 
 typedef struct cary{
-	unsigned char *array;
+	char *array;
 	int max;
 	int cur;
 } Cary;
