@@ -1,7 +1,7 @@
 
 /*
 
-Copyright (C) (2004 - 2005) (Venkata Ramana Enaganti) <ramana@intraperson.com>
+Copyright (C) (2004 - 2006) (Venkata Ramana Enaganti) <ramana@intraperson.com>
 
 This program is free software; you can redistribute it and/or 
 modify it under the terms of the GNU General Public License 
@@ -65,10 +65,17 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 /*do not check skel directory contents while copying*/
 #define SUB_OPTION_NOSKELCHECK		"noskelcheck"
+ 
+/*Do not check if directory to be created really is the
+  home directory */
+#define SUB_OPTION_NOHOMECHECK		"nohomecheck"
 
 /*group for every home directory*/
 #define SUB_OPTION_GROUP		"group"
 
+/*owner for every home directory*/
+#define SUB_OPTION_OWNER		"owner"
+
 /*Try to be fast*/
 #define SUB_OPTION_FASTMODE		"fastmode"
 
@@ -120,8 +127,10 @@ static struct {
 	int nocheck; 
 	int noskelcheck; 
 	int fastmode;
+ 	int nohomecheck;
 	mode_t mode; 
 	gid_t group; 
+	uid_t owner;
 } ah_conf;
 
 static long int pwd_bufsz;
@@ -210,6 +219,23 @@ static gid_t group_option_check( const char *val )
 	return -1;
 }
 
+static uid_t owner_option_check( const char *val )
+{
+	struct passwd *pass;
+	
+	errno = 0;
+	pass = getpwnam( val );
+	if( pass )
+		return pass->pw_uid;
+	if( ! errno )
+		msglog( MSG_FATAL, "no user found with name %s", val );
+	else
+		msglog( MSG_FATAL|LOG_ERRNO, "owner_option_check: getpwnam %s",
+						val );
+
+	return 0;
+}
+
 static void option_process( char *subopt )
 {
 	char *value;
@@ -221,8 +247,10 @@ static void option_process( char *subopt )
 		OPTION_MODE_IDX,
 		OPTION_NOCHECK_IDX,
 		OPTION_NOSKELCHECK_IDX,
+		OPTION_OWNER_IDX,
 		OPTION_GROUP_IDX,
 		OPTION_FASTMODE_IDX,
+ 		OPTION_NOHOMECHECK_IDX,
 		END
 	};
 
@@ -234,8 +262,10 @@ static void option_process( char *subopt )
 		[ OPTION_MODE_IDX     ] = SUB_OPTION_MODE,
 		[ OPTION_NOCHECK_IDX  ] = SUB_OPTION_NOCHECK,
 		[ OPTION_NOSKELCHECK_IDX ] = SUB_OPTION_NOSKELCHECK,
+		[ OPTION_OWNER_IDX    ]	= SUB_OPTION_OWNER,
 		[ OPTION_GROUP_IDX    ]	= SUB_OPTION_GROUP,
 		[ OPTION_FASTMODE_IDX ] = SUB_OPTION_FASTMODE,
+ 		[ OPTION_NOHOMECHECK_IDX ] = SUB_OPTION_NOHOMECHECK,
 		[ END                 ] = NULL
 	};
 
@@ -280,6 +310,10 @@ static void option_process( char *subopt )
 				ah_conf.noskelcheck = 1;
 				break;
 
+			case OPTION_OWNER_IDX:
+				ah_conf.owner = owner_option_check( value );
+				break;
+
 			case OPTION_GROUP_IDX:
 				ah_conf.group = group_option_check( value );
 				break;
@@ -288,6 +322,10 @@ static void option_process( char *subopt )
 				ah_conf.fastmode = 1;
 				break;
 
+ 			case OPTION_NOHOMECHECK_IDX:
+ 				ah_conf.nohomecheck = 1;
+ 				break;
+
 			default:
 				msglog( MSG_FATAL, "unknown module suboption '%s'",
 								value );
@@ -304,8 +342,10 @@ static void autohome_conf_init( char *opts )
 	ah_conf.mode = -1;
 	ah_conf.nocheck = 0;
 	ah_conf.noskelcheck = 0;
+	ah_conf.owner = -1;
 	ah_conf.group = -1;
 	ah_conf.fastmode = 0;
+ 	ah_conf.nohomecheck = 0;
 
 	option_process( opts );
 
@@ -821,7 +861,7 @@ static int get_passwd_info( const char *name, uid_t *uid,
 	errno = getpwnam_r( name, &pwd, buf, pwd_bufsz, &pass );
 	if( pass )
 	{
-		(*uid) = pass->pw_uid;
+		(*uid) = ah_conf.owner != -1 ? ah_conf.owner : pass->pw_uid;
 		(*gid) = ah_conf.group != -1 ? ah_conf.group : pass->pw_gid;
 		string_n_copy( home, pass->pw_dir ,len );
 		return 1;
@@ -854,26 +894,27 @@ int module_dowork( const char *name,
 
 	module_dir( realhome, reallen, name );
 
+	/*bypass everything if we can stat, in fast mode*/
 	if( ah_conf.fastmode && ! stat( realhome, &st ) )
 		return 1;
 
-	if( ! get_passwd_info( name, &uid, &gid,
-				home, sizeof(home) ) )
+	if( ! get_passwd_info( name, &uid, &gid, home, sizeof(home) ) )
 		return 0;
 
-	snprintf( tmp, sizeof(tmp), "%s/%s", homebase, name );
-
-	if( strcmp( home, tmp ) )
+ 	if( ( ! ah_conf.nohomecheck ) )
 	{
-		msglog( MSG_NOTICE, "home dirs %s,%s do not match",
-				home, tmp );
-		return 0;
+		snprintf( tmp, sizeof(tmp), "%s/%s", homebase, name );
+		if( strcmp( home, tmp ) ) {
+			msglog( MSG_NOTICE, "home dirs %s,%s do not match",
+					home, tmp );
+			return 0;
+		}
 	}
 
 	return create_home_dir( realhome, ah_conf.skel, uid, gid );
 }
 
-/*nothing to be done*/
 void module_clean( void )
 {
+	/*nothing to be done*/
 }
